@@ -8,6 +8,8 @@ from aiortc.contrib.media import MediaPlayer, MediaRelay
 
 
 pcs = set()
+relay = None
+webcam = None
 
 def create_local_tracks(play_from, decode, device, rtbufsize):
     global relay, webcam
