@@ -4,25 +4,29 @@ import logging
 
 import socketio
 from aiortc import MediaStreamTrack, RTCPeerConnection, RTCIceServer, RTCConfiguration
+from aiortc.contrib.media import MediaRelay
 from aiortc.rtcrtpreceiver import RemoteStreamTrack
 
+relay = MediaRelay()
+
+
+class VideoTransformTrack(MediaStreamTrack):
+    kind = "video"
+
+    def __init__(self, track, gsdbs, source, onframe):
+        super().__init__()
+        self.track = track
+        self.onframe = onframe
+        self.source = source
+        self.gsdbs = gsdbs
+
+    async def recv(self):
+        frame = await self.track.recv()
+        self.onframe(self.gsdbs, self.source, frame)
+        return frame
+
 
 class GSPeerConnectionWatcher:
-    class VideoTransformTrack(MediaStreamTrack):
-        kind = "video"
-
-        def __init__(self, track: RemoteStreamTrack, gsdbs, source, onframe):
-            super().__init__()
-            self.track = track
-            self.onframe = onframe
-            self.source = source
-            self.gsdbs = gsdbs
-
-        async def recv(self):
-            frame = await self.track.recv()
-            # frame = await self.track._queue.get()
-            # self.onframe(self.gsdbs, self.source, frame)
-            return frame
 
     @classmethod
     async def create(cls, gsdbs, target, onframe=None, onmessage=None, ontrack=None, ontrackended=None):
@@ -75,6 +79,12 @@ class GSPeerConnectionWatcher:
                     if self.ontrack is not None:
                         self.logger.info("on track received.Recording started")
                         await self.ontrack(self.gsdbs, track, self.target)
+                    if self.onframe is not None:
+                        self.logger.info("on track received. Onframe started")
+                        self.peerConnections.addTrack(
+                            VideoTransformTrack(
+                                relay.subscribe(track), self.gsdbs, self.target, self.onframe)
+                        )
 
                 @track.on("ended")
                 async def on_ended():
